@@ -19,6 +19,7 @@
 # Boston, MA 02111-1307, USA.
 #
 
+from .message import Position
 from .odict import odict
 from .utils import to_underscores
 
@@ -88,6 +89,11 @@ in contrast to the other create_type() functions."""
         fundamental = type_names.get(gtype_name)
         if fundamental is not None:
             return cls(target_fundamental=fundamental.target_fundamental)
+        if gtype_name == 'GHashTable':
+            return Map(TYPE_ANY, TYPE_ANY, gtype_name=gtype_name)
+        elif gtype_name in ('GArray', 'GPtrArray', 'GByteArray'):
+            return Array('GLib.' + gtype_name[1:], TYPE_ANY,
+                         gtype_name=gtype_name)
         return cls(gtype_name=gtype_name)
 
     def get_giname(self):
@@ -482,12 +488,12 @@ GIName.  It's possible for nodes to contain or point to other nodes."""
     def inherit_file_positions(self, node):
         self.file_positions.update(node.file_positions)
 
-    def add_file_position(self, filename, line, column):
-        self.file_positions.add((filename, line, column))
+    def add_file_position(self, position):
+        self.file_positions.add(position)
 
     def add_symbol_reference(self, symbol):
         if symbol.source_filename:
-            self.add_file_position(symbol.source_filename, symbol.line, -1)
+            self.add_file_position(Position(symbol.source_filename, symbol.line))
 
     def walk(self, callback, chain):
         res = callback(self, chain)
@@ -518,6 +524,7 @@ class Callable(Node):
         self.retval = retval
         self.parameters = parameters
         self.throws = not not throws
+        self.instance_parameter = None # Parameter
 
     def get_parameter_index(self, name):
         for i, parameter in enumerate(self.parameters):
@@ -577,7 +584,7 @@ class Array(Type):
         else:
             assert array_type in (self.GLIB_ARRAY,
                                   self.GLIB_BYTEARRAY,
-                                  self.GLIB_PTRARRAY)
+                                  self.GLIB_PTRARRAY), array_type
             self.array_type = array_type
         assert isinstance(element_type, Type)
         self.element_type = element_type
@@ -759,6 +766,7 @@ class Field(Annotated):
         self.writable = writable
         self.bits = bits
         self.anonymous_node = anonymous_node
+        self.private = False
 
     def __cmp__(self, other):
         return cmp(self.name, other.name)
